@@ -1,35 +1,36 @@
 #define HCX_DO_RCASCAN			1
-#define HCX_DEAUTH_REASON_CODE		2
-#define HCX_DISABLE_DEAUTHENTICATION	3
-#define HCX_DISABLE_AP_ATTACKS		4
-#define HCX_STOP_AP_ATTACKS		5
-#define HCX_RESUME_AP_ATTACKS		6
-#define HCX_DISABLE_CLIENT_ATTACKS	7
-#define HCX_SILENT			8
-#define HCX_GPS_DEVICE			9
-#define HCX_GPSD			10
-#define HCX_NMEA_NAME			11
-#define HCX_EAPOL_TIMEOUT		12
-#define HCX_ACTIVE_BEACON		13
-#define HCX_FLOOD_BEACON		14
-#define HCX_EXTAP_BEACON		15
-#define HCX_INFINITY			16
-#define HCX_FILTERLIST_AP		17
-#define HCX_FILTERLIST_CLIENT		18
-#define HCX_FILTERMODE			19
-#define HCX_BPFC			20
-#define HCX_WEAKCANDIDATE		21
-#define HCX_TOT				22
-#define HCX_REBOOT			23
-#define HCX_POWER_OFF			24
-#define HCX_GPIO_BUTTON			25
-#define HCX_GPIO_STATUSLED		26
-#define HCX_SERVER_PORT			27
-#define HCX_CLIENT_PORT			28
-#define HCX_CHECK_DRIVER		29
-#define HCX_CHECK_INJECTION		30
-#define HCX_ERROR_MAX			31
-#define HCX_STATUS			32
+#define HCX_DO_TARGETSCAN		2
+#define HCX_DEAUTH_REASON_CODE		3
+#define HCX_DISABLE_DEAUTHENTICATION	4
+#define HCX_DISABLE_AP_ATTACKS		5
+#define HCX_STOP_AP_ATTACKS		6
+#define HCX_RESUME_AP_ATTACKS		7
+#define HCX_DISABLE_CLIENT_ATTACKS	8
+#define HCX_SILENT			9
+#define HCX_GPS_DEVICE			10
+#define HCX_GPSD			11
+#define HCX_NMEA_NAME			12
+#define HCX_EAPOL_TIMEOUT		13
+#define HCX_ACTIVE_BEACON		14
+#define HCX_FLOOD_BEACON		15
+#define HCX_EXTAP_BEACON		16
+#define HCX_INFINITY			17
+#define HCX_FILTERLIST_AP		18
+#define HCX_FILTERLIST_CLIENT		19
+#define HCX_FILTERMODE			20
+#define HCX_BPFC			21
+#define HCX_WEAKCANDIDATE		22
+#define HCX_TOT				23
+#define HCX_REBOOT			24
+#define HCX_POWER_OFF			25
+#define HCX_GPIO_BUTTON			26
+#define HCX_GPIO_STATUSLED		27
+#define HCX_SERVER_PORT			28
+#define HCX_CLIENT_PORT			29
+#define HCX_CHECK_DRIVER		30
+#define HCX_CHECK_INJECTION		31
+#define HCX_ERROR_MAX			32
+#define HCX_STATUS			33
 #define HCX_INTERFACE_NAME		'i'
 #define HCX_PCAPNG_NAME			'o'
 #define HCX_PACPNG_FRAMES		'f'
@@ -84,6 +85,7 @@
 #define PCAPNG_FRAME_IPV6	0b00001000
 #define PCAPNG_FRAME_WEP	0b00010000
 #define PCAPNG_FRAME_WPA	0b00100000
+#define PCAPNG_FRAME_VENDOR	0b01000000
 
 #define STATUS_EAPOL		0b0000000000000001
 #define STATUS_ASSOCIATION	0b0000000000000010
